contexttools
============

.. automodule:: abjad.tools.contexttools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.contexttools.ClefMark.ClefMark.ClefMark
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory
      ~abjad.tools.contexttools.Context.Context.Context
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark
      ~abjad.tools.contexttools.DynamicMark.DynamicMark.DynamicMark
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark
      ~abjad.tools.contexttools.StaffChangeMark.StaffChangeMark.StaffChangeMark
      ~abjad.tools.contexttools.TempoMark.TempoMark.TempoMark
      ~abjad.tools.contexttools.TempoMarkInventory.TempoMarkInventory.TempoMarkInventory
      ~abjad.tools.contexttools.TimeSignatureMark.TimeSignatureMark.TimeSignatureMark
